@@ -276,6 +276,7 @@ drawable_get_adjusted_size (EelBackground *background,
 static gboolean
 eel_background_ensure_realized (EelBackground *background, GdkWindow *window)
 {
+	gpointer data;
 	GtkWidget *widget;
 	GtkStyle *style;
 	gboolean changed;
@@ -291,7 +292,8 @@ eel_background_ensure_realized (EelBackground *background, GdkWindow *window)
 	/* Set the default color */
 	
 	/* Get the widget to which the window belongs and its style as well */
-	gdk_window_get_user_data (window, (void **) &widget);
+	gdk_window_get_user_data (window, &data);
+	widget = GTK_WIDGET (data);
 	if (widget != NULL) {
 		style = gtk_widget_get_style (widget);
 		if (background->details->use_base) {
