@@ -69,7 +69,7 @@ enum
 	PROP_X_ALIGNMENT,
 	PROP_X_PADDING,
 	PROP_Y_ALIGNMENT,
-	PROP_Y_PADDING,
+	PROP_Y_PADDING
 };
 
 /* Detail member struct */
@@ -141,7 +141,7 @@ static EelDimensions labeled_image_get_image_dimensions   (const EelLabeledImage
 static EelDimensions labeled_image_get_label_dimensions   (const EelLabeledImage *labeled_image);
 static void          labeled_image_ensure_label           (EelLabeledImage       *labeled_image);
 static void          labeled_image_ensure_image           (EelLabeledImage       *labeled_image);
-static ArtIRect      labeled_image_get_content_bounds     (const EelLabeledImage *labeled_image);
+static EelIRect      labeled_image_get_content_bounds     (const EelLabeledImage *labeled_image);
 static EelDimensions labeled_image_get_content_dimensions (const EelLabeledImage *labeled_image);
 static void          labeled_image_update_alignments      (EelLabeledImage       *labeled_image);
 static gboolean      labeled_image_show_label             (const EelLabeledImage *labeled_image);
@@ -295,7 +295,7 @@ eel_labeled_image_class_init (EelLabeledImageClass *labeled_image_class)
 				      G_PARAM_READWRITE));
 }
 
-void
+static void
 eel_labeled_image_init (EelLabeledImage *labeled_image)
 {
 	GTK_WIDGET_SET_FLAGS (labeled_image, GTK_NO_WINDOW);
@@ -512,8 +512,8 @@ eel_labeled_image_size_allocate (GtkWidget *widget,
 				 GtkAllocation *allocation)
 {
 	EelLabeledImage *labeled_image;
- 	ArtIRect image_bounds;
-	ArtIRect label_bounds;
+ 	EelIRect image_bounds;
+	EelIRect label_bounds;
 
  	g_return_if_fail (EEL_IS_LABELED_IMAGE (widget));
  	g_return_if_fail (allocation != NULL);
@@ -538,7 +538,7 @@ eel_labeled_image_expose_event (GtkWidget *widget,
 				GdkEventExpose *event)
 {
 	EelLabeledImage *labeled_image;
-	ArtIRect label_bounds;
+	EelIRect label_bounds;
 
 	g_return_val_if_fail (EEL_IS_LABELED_IMAGE (widget), TRUE);
 	g_return_val_if_fail (GTK_WIDGET_REALIZED (widget), TRUE);
@@ -731,20 +731,20 @@ labeled_image_get_label_dimensions (const EelLabeledImage *labeled_image)
 	return label_dimensions;
 }
 
-static ArtIRect
+static EelIRect
 labeled_image_get_image_bounds_fill (const EelLabeledImage *labeled_image)
 {
-	ArtIRect image_bounds;
+	EelIRect image_bounds;
 	EelDimensions image_dimensions;
-	ArtIRect content_bounds;
-	ArtIRect bounds;
+	EelIRect content_bounds;
+	EelIRect bounds;
 
-	g_return_val_if_fail (EEL_IS_LABELED_IMAGE (labeled_image), eel_art_irect_empty);
+	g_return_val_if_fail (EEL_IS_LABELED_IMAGE (labeled_image), eel_irect_empty);
 
 	image_dimensions = labeled_image_get_image_dimensions (labeled_image);
 
 	if (eel_dimensions_are_empty (image_dimensions)) {
-		return eel_art_irect_empty;
+		return eel_irect_empty;
 	}
 
 	content_bounds = labeled_image_get_content_bounds (labeled_image);
@@ -781,22 +781,29 @@ labeled_image_get_image_bounds_fill (const EelLabeledImage *labeled_image)
 			image_bounds.x1 = bounds.x1;
 			image_bounds.y1 = content_bounds.y0 + image_dimensions.height;
 			break;
+
+		default:
+			image_bounds.x0 = 0;
+			image_bounds.y0 = 0;
+			image_bounds.x1 = 0;
+			image_bounds.y1 = 0;
+			g_assert_not_reached ();
 		}
 	}
 
 	return image_bounds;
 }
 
-ArtIRect
+EelIRect
 eel_labeled_image_get_image_bounds (const EelLabeledImage *labeled_image)
 {
 	EelDimensions image_dimensions;
 	EelDimensions label_dimensions;
 	GtkRequisition image_requisition;
-	ArtIRect image_bounds;
-	ArtIRect content_bounds;
+	EelIRect image_bounds;
+	EelIRect content_bounds;
 
-	g_return_val_if_fail (EEL_IS_LABELED_IMAGE (labeled_image), eel_art_irect_empty);
+	g_return_val_if_fail (EEL_IS_LABELED_IMAGE (labeled_image), eel_irect_empty);
 
 	if (labeled_image->details->fill) {
 		return labeled_image_get_image_bounds_fill (labeled_image);
@@ -814,7 +821,7 @@ eel_labeled_image_get_image_bounds (const EelLabeledImage *labeled_image)
 	label_dimensions = labeled_image_get_label_dimensions (labeled_image);
 
 	if (eel_dimensions_are_empty (image_dimensions)) {
-		return eel_art_irect_empty;
+		return eel_irect_empty;
 	}
 
 	content_bounds = labeled_image_get_content_bounds (labeled_image);
@@ -822,40 +829,40 @@ eel_labeled_image_get_image_bounds (const EelLabeledImage *labeled_image)
 	if (!labeled_image_show_label (labeled_image)) {
 		image_bounds.x0 = 
 			content_bounds.x0 +
-			(eel_art_irect_get_width (content_bounds) - image_dimensions.width) / 2;
+			(eel_irect_get_width (content_bounds) - image_dimensions.width) / 2;
 		image_bounds.y0 = 
 			content_bounds.y0 +
-			(eel_art_irect_get_height (content_bounds) - image_dimensions.height) / 2;
+			(eel_irect_get_height (content_bounds) - image_dimensions.height) / 2;
 	} else {
 		switch (labeled_image->details->label_position) {
 		case GTK_POS_LEFT:
 			image_bounds.x0 = content_bounds.x1 - image_dimensions.width;
 			image_bounds.y0 = 
 				content_bounds.y0 +
-				(eel_art_irect_get_height (content_bounds) - image_dimensions.height) / 2;
+				(eel_irect_get_height (content_bounds) - image_dimensions.height) / 2;
 			break;
 
 		case GTK_POS_RIGHT:
 			image_bounds.x0 = content_bounds.x0;
 			image_bounds.y0 = 
 				content_bounds.y0 +
-				(eel_art_irect_get_height (content_bounds) - image_dimensions.height) / 2;
+				(eel_irect_get_height (content_bounds) - image_dimensions.height) / 2;
 			break;
 
 		case GTK_POS_TOP:
 			image_bounds.x0 = 
 				content_bounds.x0 +
-				(eel_art_irect_get_width (content_bounds) - image_dimensions.width) / 2;
+				(eel_irect_get_width (content_bounds) - image_dimensions.width) / 2;
 			image_bounds.y0 = content_bounds.y1 - image_dimensions.height;
 			break;
 
 		case GTK_POS_BOTTOM:
 			image_bounds.x0 = 
 				content_bounds.x0 +
-				(eel_art_irect_get_width (content_bounds) - image_dimensions.width) / 2;
+				(eel_irect_get_width (content_bounds) - image_dimensions.width) / 2;
 				
 			if (is_fixed_height (labeled_image)) {	
-				image_bounds.y0 = content_bounds.y0 + eel_art_irect_get_height (content_bounds)
+				image_bounds.y0 = content_bounds.y0 + eel_irect_get_height (content_bounds)
 					- image_dimensions.height
 					- label_dimensions.height
 					- labeled_image->details->spacing;
@@ -864,6 +871,11 @@ eel_labeled_image_get_image_bounds (const EelLabeledImage *labeled_image)
 			}	
 
 			break;
+
+		default:
+			image_bounds.x0 = 0;
+			image_bounds.y0 = 0;
+			g_assert_not_reached ();
 		}
 	}
 	
@@ -873,20 +885,20 @@ eel_labeled_image_get_image_bounds (const EelLabeledImage *labeled_image)
 	return image_bounds;
 }
 
-static ArtIRect
+static EelIRect
 labeled_image_get_label_bounds_fill (const EelLabeledImage *labeled_image)
 {
-	ArtIRect label_bounds;
+	EelIRect label_bounds;
 	EelDimensions label_dimensions;
-	ArtIRect content_bounds;
-	ArtIRect bounds;
+	EelIRect content_bounds;
+	EelIRect bounds;
 
-	g_return_val_if_fail (EEL_IS_LABELED_IMAGE (labeled_image), eel_art_irect_empty);
+	g_return_val_if_fail (EEL_IS_LABELED_IMAGE (labeled_image), eel_irect_empty);
 
 	label_dimensions = labeled_image_get_label_dimensions (labeled_image);
 
 	if (eel_dimensions_are_empty (label_dimensions)) {
-		return eel_art_irect_empty;
+		return eel_irect_empty;
 	}
 
 	content_bounds = labeled_image_get_content_bounds (labeled_image);
@@ -925,20 +937,27 @@ labeled_image_get_label_bounds_fill (const EelLabeledImage *labeled_image)
 			label_bounds.x1 = bounds.x1;
 			label_bounds.y1 = bounds.y1;
 			break;
+
+		default:
+			label_bounds.x0 = 0;
+			label_bounds.y0 = 0;
+			label_bounds.x1 = 0;
+			label_bounds.y1 = 0;
+			g_assert_not_reached ();
 		}
 	}
 
 	return label_bounds;
 }
 
-ArtIRect
+EelIRect
 eel_labeled_image_get_label_bounds (const EelLabeledImage *labeled_image)
 {
-	ArtIRect label_bounds;
+	EelIRect label_bounds;
 	EelDimensions label_dimensions;
-	ArtIRect content_bounds;
+	EelIRect content_bounds;
 
-	g_return_val_if_fail (EEL_IS_LABELED_IMAGE (labeled_image), eel_art_irect_empty);
+	g_return_val_if_fail (EEL_IS_LABELED_IMAGE (labeled_image), eel_irect_empty);
 
 	if (labeled_image->details->fill) {
 		return labeled_image_get_label_bounds_fill (labeled_image);
@@ -947,7 +966,7 @@ eel_labeled_image_get_label_bounds (const EelLabeledImage *labeled_image)
 	label_dimensions = labeled_image_get_label_dimensions (labeled_image);
 
 	if (eel_dimensions_are_empty (label_dimensions)) {
-		return eel_art_irect_empty;
+		return eel_irect_empty;
 	}
 
 	content_bounds = labeled_image_get_content_bounds (labeled_image);
@@ -956,10 +975,10 @@ eel_labeled_image_get_label_bounds (const EelLabeledImage *labeled_image)
 	if (!labeled_image_show_image (labeled_image)) {
 		label_bounds.x0 = 
 			content_bounds.x0 +
-			(eel_art_irect_get_width (content_bounds) - label_dimensions.width) / 2;
+			(eel_irect_get_width (content_bounds) - label_dimensions.width) / 2;
 		label_bounds.y0 = 
 			content_bounds.y0 +
-			(eel_art_irect_get_height (content_bounds) - label_dimensions.height) / 2;
+			(eel_irect_get_height (content_bounds) - label_dimensions.height) / 2;
 		/* Both label and image are shown */
 	} else {
 		switch (labeled_image->details->label_position) {
@@ -967,29 +986,34 @@ eel_labeled_image_get_label_bounds (const EelLabeledImage *labeled_image)
 			label_bounds.x0 = content_bounds.x0;
 			label_bounds.y0 = 
 				content_bounds.y0 +
-				(eel_art_irect_get_height (content_bounds) - label_dimensions.height) / 2;
+				(eel_irect_get_height (content_bounds) - label_dimensions.height) / 2;
 			break;
 
 		case GTK_POS_RIGHT:
 			label_bounds.x0 = content_bounds.x1 - label_dimensions.width;
 			label_bounds.y0 = 
 				content_bounds.y0 +
-				(eel_art_irect_get_height (content_bounds) - label_dimensions.height) / 2;
+				(eel_irect_get_height (content_bounds) - label_dimensions.height) / 2;
 			break;
 
 		case GTK_POS_TOP:
 			label_bounds.x0 = 
 				content_bounds.x0 +
-				(eel_art_irect_get_width (content_bounds) - label_dimensions.width) / 2;
+				(eel_irect_get_width (content_bounds) - label_dimensions.width) / 2;
 			label_bounds.y0 = content_bounds.y0;
 			break;
 
 		case GTK_POS_BOTTOM:
 			label_bounds.x0 = 
 				content_bounds.x0 +
-				(eel_art_irect_get_width (content_bounds) - label_dimensions.width) / 2;
+				(eel_irect_get_width (content_bounds) - label_dimensions.width) / 2;
 			label_bounds.y0 = content_bounds.y1 - label_dimensions.height;
 			break;
+
+		default:
+			label_bounds.x0 = 0;
+			label_bounds.y0 = 0;
+			g_assert_not_reached ();
 		}
 	}
 	
@@ -1139,19 +1163,19 @@ labeled_image_get_content_dimensions (const EelLabeledImage *labeled_image)
 	return content_dimensions;
 }
 
-static ArtIRect
+static EelIRect
 labeled_image_get_content_bounds (const EelLabeledImage *labeled_image)
 {
 	EelDimensions content_dimensions;
-	ArtIRect content_bounds;
-	ArtIRect bounds;
+	EelIRect content_bounds;
+	EelIRect bounds;
 
-	g_return_val_if_fail (EEL_IS_LABELED_IMAGE (labeled_image), eel_art_irect_empty);
+	g_return_val_if_fail (EEL_IS_LABELED_IMAGE (labeled_image), eel_irect_empty);
 
 	bounds = eel_gtk_widget_get_bounds (GTK_WIDGET (labeled_image));
 
 	content_dimensions = labeled_image_get_content_dimensions (labeled_image);
-	content_bounds = eel_art_irect_align (bounds,
+	content_bounds = eel_irect_align (bounds,
 					      content_dimensions.width,
 					      content_dimensions.height,
 					      labeled_image->details->x_alignment,
@@ -1907,7 +1931,7 @@ button_leave_callback (GtkWidget *widget,
 
 	if (GTK_WIDGET_DRAWABLE (widget)) {
 		const int fudge = 4;
-		ArtIRect bounds;
+		EelIRect bounds;
 
 		bounds = eel_gtk_widget_get_bounds (widget);
 		
@@ -1919,8 +1943,8 @@ button_leave_callback (GtkWidget *widget,
 		gtk_widget_queue_draw_area (widget->parent,
 					    bounds.x0,
 					    bounds.y0,
-					    eel_art_irect_get_width (bounds),
-					    eel_art_irect_get_height (bounds));
+					    eel_irect_get_width (bounds),
+					    eel_irect_get_height (bounds));
 	}
 }
 
@@ -2132,7 +2156,8 @@ eel_labeled_image_accessible_get_name (AtkObject *accessible)
 
 	labeled_image = get_image (accessible);
 
-	if (labeled_image->details->label)
+	if (labeled_image && labeled_image->details &&
+	    labeled_image->details->label)
 		return gtk_label_get_text
 			(GTK_LABEL (labeled_image->details->label));
 
@@ -2222,7 +2247,7 @@ eel_labeled_image_get_accessible (GtkWidget *widget)
 	}
 
 	if (!types [i]) {
-		static const GInterfaceInfo atk_image_info = {
+		const GInterfaceInfo atk_image_info = {
 			(GInterfaceInitFunc) eel_labeled_image_accessible_image_interface_init,
 			(GInterfaceFinalizeFunc) NULL,
 			NULL
