@@ -28,6 +28,7 @@
 #include <errno.h>
 #include <locale.h>
 #include <stdlib.h>
+#include <string.h>
 
 #if !defined (EEL_OMIT_SELF_CHECK)
 #include "eel-lib-self-check-functions.h"
@@ -745,7 +746,7 @@ eel_strdup_vprintf_with_custom (EelPrintfHandler *custom,
 		if (conversions[i].precision_pos != -1) {
 			char *val;
 			
-			va_copy(va, va_orig);
+			G_VA_COPY(va, va_orig);
 			skip_to_arg (&va, args, custom, conversions[i].precision_pos);
 			val = g_strdup_vprintf ("%d", va);
 			va_end (va);
@@ -760,7 +761,7 @@ eel_strdup_vprintf_with_custom (EelPrintfHandler *custom,
 		if (conversions[i].width_pos != -1) {
 			char *val;
 			
-			va_copy(va, va_orig);
+			G_VA_COPY(va, va_orig);
 			skip_to_arg (&va, args, custom, conversions[i].width_pos);
 			val = g_strdup_vprintf ("%d", va);
 			va_end (va);
@@ -772,7 +773,7 @@ eel_strdup_vprintf_with_custom (EelPrintfHandler *custom,
 			g_free (val);
 		}
 		
-		va_copy(va, va_orig);
+		G_VA_COPY(va, va_orig);
 		skip_to_arg (&va, args, custom, conversions[i].arg_pos);
 		type = args[conversions[i].arg_pos];
 		if (type < 0) {
