@@ -55,7 +55,7 @@ struct EelWrapTableDetails
 	gboolean homogeneous;
 	GList *children;
 
-	gboolean is_scrolled : 1;
+	guint is_scrolled : 1;
 	guint cols;
 };
 
@@ -95,15 +95,11 @@ static GtkType       eel_wrap_table_child_type           (GtkContainer        *c
 
 
 /* Private EelWrapTable methods */
-static EelDimensions wrap_table_art_irect_max_dimensions (const EelDimensions *one,
+static EelDimensions wrap_table_irect_max_dimensions     (const EelDimensions *one,
 							  const EelDimensions *two);
 static EelDimensions wrap_table_get_max_child_dimensions (const EelWrapTable  *wrap_table);
 static EelDimensions wrap_table_get_content_dimensions   (const EelWrapTable  *wrap_table);
-static ArtIRect      wrap_table_get_content_bounds       (const EelWrapTable  *wrap_table);
-static EelArtIPoint  wrap_table_get_scroll_offset        (const EelWrapTable  *wrap_table);
-static GtkWidget *   wrap_table_find_child_at_point      (const EelWrapTable  *wrap_table,
-							  int                  x,
-							  int                  y);
+static EelIRect      wrap_table_get_content_bounds       (const EelWrapTable  *wrap_table);
 static gboolean      wrap_table_child_focus_in           (GtkWidget           *widget,
 							  GdkEventFocus       *event,
 							  gpointer             data);
@@ -497,9 +493,10 @@ wrap_table_get_num_fitting (int available,
 {
 	int num;
 
-  	g_return_val_if_fail (available >= 0, 0);
   	g_return_val_if_fail (max_child_size > 0, 0);
   	g_return_val_if_fail (spacing >= 0, 0);
+
+	available = MAX (available, 0);
 	
 	num = (available + spacing) / (max_child_size + spacing);
 	num = MAX (num, 1);
@@ -511,9 +508,9 @@ static void
 wrap_table_layout (EelWrapTable *wrap_table)
 {
 	GList *iterator;
-	EelArtIPoint pos;
+	EelIPoint pos;
 	EelDimensions max_child_dimensions;
-	ArtIRect content_bounds;
+	EelIRect content_bounds;
 	guint num_cols;
 
  	g_return_if_fail (EEL_IS_WRAP_TABLE (wrap_table));
@@ -523,7 +520,8 @@ wrap_table_layout (EelWrapTable *wrap_table)
 	pos.x = content_bounds.x0;
 	pos.y = content_bounds.y0;
 
-	num_cols = wrap_table_get_num_fitting (GTK_WIDGET (wrap_table)->allocation.width,
+	num_cols = wrap_table_get_num_fitting (GTK_WIDGET (wrap_table)->allocation.width -
+					       GTK_CONTAINER (wrap_table)->border_width * 2,
 					       wrap_table->details->x_spacing,
 					       max_child_dimensions.width);
 	if (num_cols != wrap_table->details->cols) {
@@ -605,7 +603,7 @@ wrap_table_layout (EelWrapTable *wrap_table)
 }
 
 static EelDimensions
-wrap_table_art_irect_max_dimensions (const EelDimensions *one,
+wrap_table_irect_max_dimensions (const EelDimensions *one,
 				     const EelDimensions *two)
 {
 	EelDimensions max_dimensions;
@@ -643,7 +641,7 @@ wrap_table_get_max_child_dimensions (const EelWrapTable *wrap_table)
 			child_dimensions.width = (int) child_requisition.width;
 			child_dimensions.height = (int) child_requisition.height;
 
-			max_dimensions = wrap_table_art_irect_max_dimensions (&child_dimensions, &max_dimensions);
+			max_dimensions = wrap_table_irect_max_dimensions (&child_dimensions, &max_dimensions);
 		}
 	}
 
@@ -674,7 +672,8 @@ wrap_table_get_content_dimensions (const EelWrapTable *wrap_table)
 		max_child_dimensions.width = MAX (max_child_dimensions.width, 1);
 		max_child_dimensions.height = MAX (max_child_dimensions.height, 1);
 
-		num_cols = wrap_table_get_num_fitting (dimensions.width,
+		num_cols = wrap_table_get_num_fitting (dimensions.width -
+						       GTK_CONTAINER (wrap_table)->border_width * 2,
 						       wrap_table->details->x_spacing,
 						       max_child_dimensions.width);
 		num_rows = num_children / num_cols;
@@ -694,12 +693,12 @@ wrap_table_get_content_dimensions (const EelWrapTable *wrap_table)
 	return content_dimensions;
 }
 
-static ArtIRect
+static EelIRect
 wrap_table_get_content_bounds (const EelWrapTable *wrap_table)
 {
-	ArtIRect content_bounds;
+	EelIRect content_bounds;
 
-  	g_return_val_if_fail (EEL_IS_WRAP_TABLE (wrap_table), eel_art_irect_empty);
+  	g_return_val_if_fail (EEL_IS_WRAP_TABLE (wrap_table), eel_irect_empty);
 
 	content_bounds = eel_gtk_widget_get_bounds (GTK_WIDGET (wrap_table));
 
@@ -711,30 +710,6 @@ wrap_table_get_content_bounds (const EelWrapTable *wrap_table)
 	return content_bounds;
 }
 
-static EelArtIPoint
-wrap_table_get_scroll_offset (const EelWrapTable *wrap_table)
-{
-	EelArtIPoint scroll_offset;
-	GtkWidget *parent;
-
-  	g_return_val_if_fail (EEL_IS_WRAP_TABLE (wrap_table), eel_art_ipoint_zero);
-
-	scroll_offset = eel_art_ipoint_zero;
-
-	parent = GTK_WIDGET (wrap_table)->parent;
-
-	/* FIXME: It lame we have to hardcode for a possible viewport 
-	 * parent here.  Theres probably a better way to do this
-	 */
-	if (GTK_IS_VIEWPORT (parent)) {
-		gdk_window_get_position (GTK_VIEWPORT (parent)->bin_window,
-					 &scroll_offset.x,
-					 &scroll_offset.y);
-	}
-
-	return scroll_offset;
-}
-
 static gboolean
 wrap_table_child_focus_in (GtkWidget *widget, 
 			   GdkEventFocus *event, 
@@ -749,34 +724,6 @@ wrap_table_child_focus_in (GtkWidget *widget,
 	return FALSE;
 }
 
-static GtkWidget *
-wrap_table_find_child_at_point (const EelWrapTable *wrap_table,
-			       int x,
-			       int y)
-{
-	GList *iterator;
-	
-  	g_return_val_if_fail (EEL_IS_WRAP_TABLE (wrap_table), NULL);
-
-	for (iterator = wrap_table->details->children; iterator; iterator = iterator->next) {
-		GtkWidget *child;
-		
-		child = iterator->data;
-		
-		if (GTK_WIDGET_VISIBLE (child)) {
-			ArtIRect child_bounds;
-
-			child_bounds = eel_gtk_widget_get_bounds (child);
- 			
-			if (eel_art_irect_contains_point (child_bounds, x, y)) {
-				return child;
-			}
-		}
-	}
-
-	return NULL;
-}
-
 /**
  * eel_wrap_table_new:
  *
@@ -863,6 +810,7 @@ eel_wrap_table_get_y_spacing (const EelWrapTable *wrap_table)
 	return wrap_table->details->y_spacing;
 }
 
+
 /**
  * eel_wrap_table_find_child_at_event_point:
  * @wrap_table: A EelWrapTable.
@@ -873,18 +821,30 @@ eel_wrap_table_get_y_spacing (const EelWrapTable *wrap_table)
  */
 GtkWidget *
 eel_wrap_table_find_child_at_event_point (const EelWrapTable *wrap_table,
-					       int x,
-					       int y)
+					  int x,
+					  int y)
 {
-	EelArtIPoint scroll_offset;
-
-	g_return_val_if_fail (EEL_IS_WRAP_TABLE (wrap_table), NULL);
-
-	scroll_offset = wrap_table_get_scroll_offset (wrap_table);
+	GList *iterator;
 	
-	return wrap_table_find_child_at_point (wrap_table,
-					      x + ABS (scroll_offset.x),
-					      y + ABS (scroll_offset.y));
+  	g_return_val_if_fail (EEL_IS_WRAP_TABLE (wrap_table), NULL);
+
+	for (iterator = wrap_table->details->children; iterator; iterator = iterator->next) {
+		GtkWidget *child;
+		
+		child = iterator->data;
+		
+		if (GTK_WIDGET_VISIBLE (child)) {
+			EelIRect child_bounds;
+
+			child_bounds = eel_gtk_widget_get_bounds (child);
+ 			
+			if (eel_irect_contains_point (child_bounds, x, y)) {
+				return child;
+			}
+		}
+	}
+
+	return NULL;
 }
 
 /**
